==> ubo_app-1.3.1.dev5725052410397491015.tar.gz: ubo_app-1.3.1.dev5725052410397491015/ubo_app/services/090-assistant/reducer.py <==
# ruff: noqa: D100, D101, D102, D103, D104, D107, N999
from __future__ import annotations

from dataclasses import replace
from typing import TYPE_CHECKING, TypeAlias

from redux import CompleteReducerResult, InitializationActionError
from redux.basic_types import InitAction

from ubo_app.store.services.assistant import (
    AssistantDownloadOllamaModelAction,
    AssistantDownloadOllamaModelEvent,
    AssistantEvent,
    AssistantProcessSpeechEvent,
    AssistantSetActiveEngineAction,
    AssistantState,
)
from ubo_app.store.services.speech_recognition import (
    SpeechRecognitionReportSpeechAction,
)

if TYPE_CHECKING:
    from redux import ReducerResult

Action: TypeAlias = InitAction | SpeechRecognitionReportSpeechAction


def reducer(
    state: AssistantState | None,
    action: Action,
) -> ReducerResult[AssistantState, None, AssistantEvent]:
    if state is None:
        if isinstance(action, InitAction):
            return AssistantState()

        raise InitializationActionError(action)

    if isinstance(action, AssistantSetActiveEngineAction):
        return replace(state, active_engine=action.engine)

    if isinstance(action, AssistantDownloadOllamaModelAction):
        return CompleteReducerResult(
            state=state,
            events=[AssistantDownloadOllamaModelEvent(model=action.model)],
        )

    if isinstance(action, SpeechRecognitionReportSpeechAction):
        return CompleteReducerResult(
            state=state,
            events=[
                AssistantProcessSpeechEvent(
                    raw_audio=action.raw_audio,
                    text=action.text,
                ),
            ],
        )

    return state

==> ubo_app-1.5.0.tar.gz: ubo_app-1.5.0/ubo_app/services/090-assistant/reducer.py <==
# ruff: noqa: D100, D101, D102, D103, D104, D107, N999
from __future__ import annotations

from dataclasses import replace
from typing import TYPE_CHECKING

from redux import CompleteReducerResult, InitializationActionError
from redux.basic_types import InitAction

from ubo_app.store.services.assistant import (
    AssistantAction,
    AssistantDownloadOllamaModelAction,
    AssistantDownloadOllamaModelEvent,
    AssistantEvent,
    AssistantProcessSpeechEvent,
    AssistantSetIsActiveAction,
    AssistantSetSelectedEngineAction,
    AssistantSetSelectedModelAction,
    AssistantState,
)
from ubo_app.store.services.speech_recognition import (
    SpeechRecognitionReportSpeechAction,
)

if TYPE_CHECKING:
    from redux import ReducerResult


def reducer(
    state: AssistantState | None,
    action: AssistantAction,
) -> ReducerResult[AssistantState, None, AssistantEvent]:
    if state is None:
        if isinstance(action, InitAction):
            return AssistantState()

        raise InitializationActionError(action)

    if isinstance(action, AssistantSetIsActiveAction):
        return replace(state, is_active=action.is_active)

    if isinstance(action, AssistantSetSelectedEngineAction):
        return replace(state, selected_engine=action.engine_name)

    if isinstance(action, AssistantSetSelectedModelAction):
        return replace(
            state,
            selected_models={
                **state.selected_models,
                state.selected_engine: action.model,
            },
        )

    if isinstance(action, AssistantDownloadOllamaModelAction):
        return CompleteReducerResult(
            state=state,
            events=[AssistantDownloadOllamaModelEvent(model=action.model)],
        )

    if isinstance(action, SpeechRecognitionReportSpeechAction):
        return CompleteReducerResult(
            state=state,
            events=[
                AssistantProcessSpeechEvent(
                    audio=action.audio,
                    text=action.text,
                ),
            ],
        )

    return state
